LSM6DSOX Simple test
--------------------

Ensure your LSM6DSOX device works with this simple test.

.. literalinclude:: ../examples/lsm6ds_lsm6dsox_simpletest.py
    :caption: examples/lsm6ds_lsm6dsox_simpletest.py
    :linenos:


LSM6DSO32 Simple test
---------------------

Ensure your LSM6DSO32 device works with this simple test.

.. literalinclude:: ../examples/lsm6ds_lsm6dso32_simpletest.py
    :caption: examples/lsm6ds_lsm6dso32_simpletest.py
    :linenos:


LSM6DS Simple test
------------------

Ensure your LSM6DS device works with this simple test.

.. literalinclude:: ../examples/lsm6ds_lsm6ds33_simpletest.py
    :caption: examples/lsm6ds_lsm6ds33_simpletest.py
    :linenos:


ISM330DHCX Simple test
----------------------

Ensure your ISM330DHCX device works with this simple test.

.. literalinclude:: ../examples/lsm6ds_ism330dhcx_simpletest.py
    :caption: examples/lsm6ds_ism330dhcx_simpletest.py
    :linenos:


LSM6DS Full test
----------------

LSM6DS Full tests

.. literalinclude:: ../examples/lsm6ds_full_test.py
    :caption: examples/lsm6ds_full_test.py
    :linenos:


Pedometer Example
-----------------

Example showing how to use the device as a pedometer

.. literalinclude:: ../examples/lsm6ds_pedometer.py
    :caption: examples/lsm6ds_pedometer.py
    :linenos:


Rate test
------------

Example showing a Rate test

.. literalinclude:: ../examples/lsm6ds_rate_test.py
    :caption: examples/lsm6ds_rate_test.py
    :linenos:
